@@ -6,11 +6,8 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use super::{
-    plain_message::PlainMessage,
-    section::{MemberInfo, SectionAuthorityProvider},
-    signed::Signed,
-};
+use super::{plain_message::PlainMessage, section::MemberInfo, signed::Signed};
+use crate::SectionAuthorityProvider;
 use ed25519_dalek::{PublicKey, Signature};
 use hex_fmt::HexFmt;
 use secured_linked_list::SecuredLinkedList;
@@ -76,7 +73,7 @@ pub enum Proposal {
         // Previous name if relocated.
         previous_name: Option<XorName>,
         // The key of the destination section that the joining node knows, if any.
-        their_knowledge: Option<BlsPublicKey>,
+        destination_key: Option<BlsPublicKey>,
     },
 
     // Proposal to remove a node from our section
