@@ -32,7 +32,7 @@ pub struct WireMsg {
 impl WireMsg {
     /// Creates a new instance keeping a (serialized) copy of the 'SectionInfo' message provided.
     pub fn new_section_info_msg(
-        query: &section_info::Message,
+        query: &section_info::SectionInfoMsg,
         dest: XorName,
         dest_section_pk: PublicKey,
     ) -> Result<Self> {
@@ -90,7 +90,7 @@ impl WireMsg {
         })?;
 
         Ok(Self {
-            header: WireMsgHeader::new(msg.id(), MessageKind::Routing, dest, dest_section_pk, None),
+            header: WireMsgHeader::new(msg.id, MessageKind::Routing, dest, dest_section_pk, None),
             payload: Bytes::from(payload_vec),
         })
     }
@@ -159,7 +159,7 @@ impl WireMsg {
 
         match self.header.kind() {
             MessageKind::SectionInfo => {
-                let msg: section_info::Message =
+                let msg: section_info::SectionInfoMsg =
                     rmp_serde::from_slice(&self.payload).map_err(|err| {
                         Error::FailedToParse(format!(
                             "Client message payload as Msgpack: {}",
@@ -247,7 +247,7 @@ impl WireMsg {
     /// Convenience function which creates a temporary WireMsg from the provided
     /// MsgEnvelope, returning the serialized WireMsg.
     pub fn serialize_section_info_msg(
-        query: &section_info::Message,
+        query: &section_info::SectionInfoMsg,
         dest: XorName,
         dest_section_pk: PublicKey,
     ) -> Result<Bytes> {
@@ -316,10 +316,7 @@ mod tests {
         let dest = XorName::random();
         let dest_section_pk = SecretKey::random().public_key();
 
-        let query = section_info::Message::GetSectionQuery {
-            public_key: dest_section_pk.into(),
-            is_node: true,
-        };
+        let query = section_info::SectionInfoMsg::GetSectionQuery(dest_section_pk.into());
         let wire_msg = WireMsg::new_section_info_msg(&query, dest, dest_section_pk)?;
         let serialized = wire_msg.serialize()?;
 
@@ -351,10 +348,7 @@ mod tests {
         let dest = XorName::random();
         let dest_section_pk = SecretKey::random().public_key();
 
-        let query = section_info::Message::GetSectionQuery {
-            public_key: dest_section_pk.into(),
-            is_node: true,
-        };
+        let query = section_info::SectionInfoMsg::GetSectionQuery(dest_section_pk.into());
         let mut wire_msg = WireMsg::new_section_info_msg(&query, dest, dest_section_pk)?;
         let serialized = wire_msg.serialize()?;
 
